@@ -696,19 +696,23 @@ class TestConfigTestEnv:
         assert envconfig.setenv['ANOTHER_VAL'] == 'else'
 
     @pytest.mark.parametrize("plat", ["win32", "linux2"])
-    def test_passenv(self, tmpdir, newconfig, monkeypatch, plat):
+    def test_passenv_as_multiline_list(self, tmpdir, newconfig, monkeypatch, plat):
         monkeypatch.setattr(sys, "platform", plat)
         monkeypatch.setenv("A123A", "a")
         monkeypatch.setenv("A123B", "b")
         monkeypatch.setenv("BX23", "0")
         config = newconfig("""
             [testenv]
-            passenv = A123* B?23
+            passenv =
+                      A123*
+                      # isolated comment
+                      B?23
         """)
         assert len(config.envconfigs) == 1
         envconfig = config.envconfigs['python']
         if plat == "win32":
             assert "PATHEXT" in envconfig.passenv
+            assert "SYSTEMDRIVE" in envconfig.passenv
             assert "SYSTEMROOT" in envconfig.passenv
             assert "TEMP" in envconfig.passenv
             assert "TMP" in envconfig.passenv
@@ -716,26 +720,86 @@ class TestConfigTestEnv:
             assert "TMPDIR" in envconfig.passenv
         assert "PATH" in envconfig.passenv
         assert "PIP_INDEX_URL" in envconfig.passenv
+        assert "LANG" in envconfig.passenv
+        assert "A123A" in envconfig.passenv
+        assert "A123B" in envconfig.passenv
+
+    @pytest.mark.parametrize("plat", ["win32", "linux2"])
+    def test_passenv_as_space_separated_list(self, tmpdir, newconfig, monkeypatch, plat):
+        monkeypatch.setattr(sys, "platform", plat)
+        monkeypatch.setenv("A123A", "a")
+        monkeypatch.setenv("A123B", "b")
+        monkeypatch.setenv("BX23", "0")
+        config = newconfig("""
+            [testenv]
+            passenv =
+                      # comment
+                      A123*  B?23
+        """)
+        assert len(config.envconfigs) == 1
+        envconfig = config.envconfigs['python']
+        if plat == "win32":
+            assert "PATHEXT" in envconfig.passenv
+            assert "SYSTEMDRIVE" in envconfig.passenv
+            assert "SYSTEMROOT" in envconfig.passenv
+            assert "TEMP" in envconfig.passenv
+            assert "TMP" in envconfig.passenv
+        else:
+            assert "TMPDIR" in envconfig.passenv
+        assert "PATH" in envconfig.passenv
+        assert "PIP_INDEX_URL" in envconfig.passenv
+        assert "LANG" in envconfig.passenv
         assert "A123A" in envconfig.passenv
         assert "A123B" in envconfig.passenv
 
     def test_passenv_with_factor(self, tmpdir, newconfig, monkeypatch):
         monkeypatch.setenv("A123A", "a")
         monkeypatch.setenv("A123B", "b")
+        monkeypatch.setenv("A123C", "c")
+        monkeypatch.setenv("A123D", "d")
         monkeypatch.setenv("BX23", "0")
+        monkeypatch.setenv("CCA43", "3")
+        monkeypatch.setenv("CB21", "4")
         config = newconfig("""
             [tox]
             envlist = {x1,x2}
             [testenv]
             passenv =
-                x1: A123A
-                x2: A123B
+                x1: A123A CC*
+                x1: CB21
+                # passed to both environments
+                A123C
+                x2: A123B A123D
         """)
         assert len(config.envconfigs) == 2
+
         assert "A123A" in config.envconfigs["x1"].passenv
+        assert "A123C" in config.envconfigs["x1"].passenv
+        assert "CCA43" in config.envconfigs["x1"].passenv
+        assert "CB21" in config.envconfigs["x1"].passenv
         assert "A123B" not in config.envconfigs["x1"].passenv
+        assert "A123D" not in config.envconfigs["x1"].passenv
+        assert "BX23" not in config.envconfigs["x1"].passenv
+
         assert "A123B" in config.envconfigs["x2"].passenv
+        assert "A123D" in config.envconfigs["x2"].passenv
         assert "A123A" not in config.envconfigs["x2"].passenv
+        assert "A123C" in config.envconfigs["x2"].passenv
+        assert "CCA43" not in config.envconfigs["x2"].passenv
+        assert "CB21" not in config.envconfigs["x2"].passenv
+        assert "BX23" not in config.envconfigs["x2"].passenv
+
+    def test_passenv_from_global_env(self, tmpdir, newconfig, monkeypatch):
+        monkeypatch.setenv("A1", "a1")
+        monkeypatch.setenv("A2", "a2")
+        monkeypatch.setenv("TOX_TESTENV_PASSENV", "A1")
+        config = newconfig("""
+            [testenv]
+            passenv = A2
+        """)
+        env = config.envconfigs["python"]
+        assert "A1" in env.passenv
+        assert "A2" in env.passenv
 
     def test_changedir_override(self, tmpdir, newconfig):
         config = newconfig("""
@@ -1271,6 +1335,17 @@ class TestGlobalOptions:
         assert config.envlist == \
             ["py26-dep1", "py26-dep2", "py27-dep1", "py27-dep2"]
 
+    def test_envlist_multiline(self, newconfig):
+        inisource = """
+            [tox]
+            envlist =
+              py27
+              py34
+        """
+        config = newconfig([], inisource)
+        assert config.envlist == \
+            ["py27", "py34"]
+
     def test_minversion(self, tmpdir, newconfig, monkeypatch):
         inisource = """
             [tox]
