@@ -283,10 +283,6 @@ def tox_addoption(parser):
     parser.add_argument("--develop", action="store_true", dest="develop",
                         help="install package in the venv using 'setup.py develop' via "
                              "'pip -e .'")
-    parser.add_argument("--set-home", action="store_true", dest="sethome",
-                        help="(experimental) force creating a new $HOME for each test "
-                             "environment and create .pydistutils.cfg|pip.conf files "
-                             "if index servers are specified with tox. ")
     parser.add_argument('-i', action="append",
                         dest="indexurl", metavar="URL",
                         help="set indexserver url (if URL is of form name=url set the "
@@ -300,10 +296,8 @@ def tox_addoption(parser):
                         help="force recreation of virtual environments")
     parser.add_argument("--result-json", action="store",
                         dest="resultjson", metavar="PATH",
-                        help="write a json file with detailed information about "
-                             "all commands and results involved.  This will turn off "
-                             "pass-through output from running test commands which is "
-                             "instead captured into the json result file.")
+                        help="write a json file with detailed information "
+                        "about all commands and results involved.")
 
     # We choose 1 to 4294967295 because it is the range of PYTHONHASHSEED.
     parser.add_argument("--hashseed", action="store",
@@ -387,15 +381,26 @@ def tox_addoption(parser):
         help="list of X=Y lines with environment variable settings")
 
     def passenv(testenv_config, value):
-        passenv = set(["PATH", "PIP_INDEX_URL"])
+        # Flatten the list to deal with space-separated values.
+        value = list(
+            itertools.chain.from_iterable(
+                [x.split(' ') for x in value]))
+
+        passenv = set(["PATH", "PIP_INDEX_URL", "LANG"])
+
+        # read in global passenv settings
+        p = os.environ.get("TOX_TESTENV_PASSENV", None)
+        if p is not None:
+            passenv.update(x for x in p.split() if x)
 
         # we ensure that tmp directory settings are passed on
         # we could also set it to the per-venv "envtmpdir"
         # but this leads to very long paths when run with jenkins
         # so we just pass it on by default for now.
         if sys.platform == "win32":
-            passenv.add("SYSTEMROOT")  # needed for python's crypto module
-            passenv.add("PATHEXT")     # needed for discovering executables
+            passenv.add("SYSTEMDRIVE")  # needed for pip6
+            passenv.add("SYSTEMROOT")   # needed for python's crypto module
+            passenv.add("PATHEXT")      # needed for discovering executables
             passenv.add("TEMP")
             passenv.add("TMP")
         else:
@@ -407,9 +412,12 @@ def tox_addoption(parser):
         return passenv
 
     parser.add_testenv_attribute(
-        name="passenv", type="space-separated-list", postprocess=passenv,
-        help="environment variables names which shall be passed "
-             "from tox invocation to test environment when executing commands.")
+        name="passenv", type="line-list", postprocess=passenv,
+        help="environment variables needed during executing test commands "
+             "(taken from invocation environment). Note that tox always "
+             "passes through some basic environment variables which are "
+             "needed for basic functioning of the Python system. "
+             "See --showconfig for the eventual passenv setting.")
 
     parser.add_testenv_attribute(
         name="whitelist_externals", type="line-list",
@@ -730,6 +738,8 @@ class parseini:
 def _split_env(env):
     """if handed a list, action="append" was used for -e """
     if not isinstance(env, list):
+        if '\n' in env:
+            env = ','.join(env.split('\n'))
         env = [env]
     return mapcat(_expand_envstr, env)
 
@@ -908,7 +918,7 @@ class SectionReader:
 
         if envkey not in os.environ and default is None:
             raise tox.exception.ConfigError(
-                "substitution env:%r: unkown environment variable %r" %
+                "substitution env:%r: unknown environment variable %r" %
                 (envkey, envkey))
 
         return os.environ.get(envkey, default)
