@@ -46,6 +46,12 @@ def show_help(config):
     tw = py.io.TerminalWriter()
     tw.write(config._parser._format_help())
     tw.line()
+    tw.line("Environment variables", bold=True)
+    tw.line("TOXENV: comma separated list of environments "
+            "(overridable by '-e')")
+    tw.line("TOX_TESTENV_PASSENV: space-separated list of extra "
+            "environment variables to be passed into test command "
+            "environemnts")
 
 
 def show_help_ini(config):
@@ -415,6 +421,9 @@ class Session:
             path.ensure(dir=1)
 
     def setupenv(self, venv):
+        if not venv.matching_platform():
+            venv.status = "platform mismatch"
+            return  # we simply omit non-matching platforms
         action = self.newaction(venv, "getenv", venv.envconfig.envdir)
         with action:
             venv.status = 0
@@ -512,9 +521,6 @@ class Session:
         if self.config.option.sdistonly:
             return
         for venv in self.venvlist:
-            if not venv.matching_platform():
-                venv.status = "platform mismatch"
-                continue  # we simply omit non-matching platforms
             if self.setupenv(venv):
                 if venv.envconfig.usedevelop:
                     self.developpkg(venv, self.config.setupdir)
@@ -563,7 +569,7 @@ class Session:
                     self.report.error(msg)
             elif status == "platform mismatch":
                 msg = "  %s: %s" % (venv.envconfig.envname, str(status))
-                self.report.verbosity1(msg)
+                self.report.skip(msg)
             elif status and status != "skipped tests":
                 msg = "  %s: %s" % (venv.envconfig.envname, str(status))
                 self.report.error(msg)
